badblocks: rename badblocks_free to badblocks_exit

For symmetry with badblocks_init() make it clear that this path only
destroys incremental allocations of a badblocks instance, and does not
free the badblocks instance itself.

Signed-off-by: Dan Williams <dan.j.williams@intel.com>
diff --git a/block/genhd.c b/block/genhd.c
index 88579cf..f463c67 100644
--- a/block/genhd.c
+++ b/block/genhd.c
@@ -671,7 +671,7 @@
 	blk_unregister_region(disk_devt(disk), disk->minors);
 
 	if (disk->bb) {
-		badblocks_free(disk->bb);
+		badblocks_exit(disk->bb);
 		kfree(disk->bb);
 	}
 
diff --git a/drivers/md/md.c b/drivers/md/md.c
index 1e48aa9..96a9918 100644
--- a/drivers/md/md.c
+++ b/drivers/md/md.c
@@ -710,7 +710,7 @@
 		put_page(rdev->bb_page);
 		rdev->bb_page = NULL;
 	}
-	badblocks_free(&rdev->badblocks);
+	badblocks_exit(&rdev->badblocks);
 }
 EXPORT_SYMBOL_GPL(md_rdev_clear);
 
diff --git a/include/linux/badblocks.h b/include/linux/badblocks.h
index 9293446..2d98c02 100644
--- a/include/linux/badblocks.h
+++ b/include/linux/badblocks.h
@@ -48,6 +48,6 @@
 ssize_t badblocks_store(struct badblocks *bb, const char *page, size_t len,
 			int unack);
 int badblocks_init(struct badblocks *bb, int enable);
-void badblocks_free(struct badblocks *bb);
+void badblocks_exit(struct badblocks *bb);
 
 #endif
diff --git a/block/badblocks.c b/block/badblocks.c
index 96aeb91..fabf6b6 100644
--- a/block/badblocks.c
+++ b/block/badblocks.c
@@ -550,12 +550,12 @@
 EXPORT_SYMBOL_GPL(badblocks_init);
 
 /**
  * badblocks_free() - free the badblocks structure
  * @bb:		the badblocks structure that holds all badblock information
  */
-void badblocks_free(struct badblocks *bb)
+void badblocks_exit(struct badblocks *bb)
 {
 	kfree(bb->page);
 	bb->page = NULL;
 }
-EXPORT_SYMBOL_GPL(badblocks_free);
+EXPORT_SYMBOL_GPL(badblocks_exit);
@@ -550,12 +550,12 @@
 
 /**
- * badblocks_free() - free the badblocks structure
+ * badblocks_exit() - free the badblocks structure
  * @bb:		the badblocks structure that holds all badblock information
  */